==> regina-normal_6.0.1.orig.tar.gz: regina-6.0.1/testsuite/maths/testmaths.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Test Suite                                                            *
 *                                                                        *
 *  Copyright (c) 1999-2021, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/**
 * This file allows all tests from this directory to be added to
 * the overall test runner, without requiring any further inclusion
 * of headers that define the specific corresponding test fixtures.
 *
 * The routines declared below (which should add tests to the given
 * test runner) should be implemented in this directory and then called
 * from the top-level test suite directory.
 */

#include <cppunit/ui/text/TestRunner.h>

void addCyclotomic(CppUnit::TextUi::TestRunner& runner);
void addMatrixOps(CppUnit::TextUi::TestRunner& runner);
void addInteger(CppUnit::TextUi::TestRunner& runner);
void addLaurent(CppUnit::TextUi::TestRunner& runner);
void addLaurent2(CppUnit::TextUi::TestRunner& runner);
void addPerm(CppUnit::TextUi::TestRunner& runner);
void addPerm2(CppUnit::TextUi::TestRunner& runner);
void addPerm3(CppUnit::TextUi::TestRunner& runner);
void addPerm4(CppUnit::TextUi::TestRunner& runner);
void addPerm5(CppUnit::TextUi::TestRunner& runner);
void addPolynomial(CppUnit::TextUi::TestRunner& runner);
void addPrimes(CppUnit::TextUi::TestRunner& runner);
void addRational(CppUnit::TextUi::TestRunner& runner);
void addNumberTheory(CppUnit::TextUi::TestRunner& runner);
void addPermConv(CppUnit::TextUi::TestRunner& runner);

==> regina-normal_7.0.orig.tar.gz: regina-7.0/testsuite/maths/testmaths.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Test Suite                                                            *
 *                                                                        *
 *  Copyright (c) 1999-2021, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/**
 * This file allows all tests from this directory to be added to
 * the overall test runner, without requiring any further inclusion
 * of headers that define the specific corresponding test fixtures.
 *
 * The routines declared below (which should add tests to the given
 * test runner) should be implemented in this directory and then called
 * from the top-level test suite directory.
 */

#include <cppunit/ui/text/TestRunner.h>

void addBinomial(CppUnit::TextUi::TestRunner& runner);
void addCyclotomic(CppUnit::TextUi::TestRunner& runner);
void addMatrix(CppUnit::TextUi::TestRunner& runner);
void addMatrixOps(CppUnit::TextUi::TestRunner& runner);
void addInteger(CppUnit::TextUi::TestRunner& runner);
void addLaurent(CppUnit::TextUi::TestRunner& runner);
void addLaurent2(CppUnit::TextUi::TestRunner& runner);
void addPerm(CppUnit::TextUi::TestRunner& runner);
void addPerm2(CppUnit::TextUi::TestRunner& runner);
void addPerm3(CppUnit::TextUi::TestRunner& runner);
void addPerm4(CppUnit::TextUi::TestRunner& runner);
void addPerm5(CppUnit::TextUi::TestRunner& runner);
void addPerm6(CppUnit::TextUi::TestRunner& runner);
void addPerm7(CppUnit::TextUi::TestRunner& runner);
void addPolynomial(CppUnit::TextUi::TestRunner& runner);
void addPrimes(CppUnit::TextUi::TestRunner& runner);
void addRational(CppUnit::TextUi::TestRunner& runner);
void addNumberTheory(CppUnit::TextUi::TestRunner& runner);
void addPermConv(CppUnit::TextUi::TestRunner& runner);
